#!/usr/bin/env python3
##
## -----------------------------------------------------------------
##    This file is part of WAPT Software Deployment
##    Copyright (C) 2012 - 2020  Tranquil IT https://www.tranquil.it
##    All Rights Reserved.
##
##    WAPT helps systems administrators to efficiently deploy
##    setup, update and configure applications.
## ------------------------------------------------------------------
##
import json
import logging
import waptserver.globalsupdate as gl

from waptserver.tasks import huey, crontab, tasks_config_file, conf
from waptserver.glpi_upload_hosts import upload_hosts_inventories

gl.reload_globals()

@huey.periodic_task(crontab(hour="*/"+str(conf['glpi_inventory_update_delay']), minute="0"))
@huey.lock_task('glpi_inventories_cron')
def upload_to_glpi_cron(force=False):
    if not conf['glpi_server_endpoint']:
        return
    if not (conf['glpi_server_user'] and conf['glpi_server_pass']):
        logger = logging.getLogger('glpiinventory.cron')
        logger.error('Missing parameter for connecting to Glpi server -> (user, pass, url)')
        return

    gl.update('glpi_inventory_upload_status', 0)
    server_timeout = [float(v) for v in conf['glpi_server_pause_timeout'].split(',')]

    upload_hosts_inventories(conf['glpi_server_user'], conf['glpi_server_pass'], conf['glpi_server_endpoint'],
        update_uploaded_hashes_every=conf['glpi_inventory_update_range'], pause_at_latency=server_timeout, force=force, debug_dir = conf.get('glpi_inventory_debug_directory'))

